@@ -13,6 +13,8 @@ from django.utils import timezone
 import subprocess,sys,mxpi,os,json,time
 from app import models
 import threading
+import requests
+import base64
 
 
 # Create your views here.
@@ -109,3 +111,48 @@ def files(request):
                     f.write(line)
             return HttpResponse('ok')
  
+def get_c(request):
+    try:
+        name=request.GET.get('name')
+        file='example/'+name+'.mxpi'
+        print(file)
+        if os.path.exists(file):
+            f=open(file,'r',encoding='utf-8')
+            c=f.read()
+            return HttpResponse(json.dumps({'msg':'ok','data':c}))
+        else:
+            return HttpResponse(json.dumps({'msg':'err','data':''}))
+    except:
+         return HttpResponse(json.dumps({'msg':'err','data':''}))
+
+
+def read_model_list(request):
+    try:
+        rq = requests.get('http://120.79.209.170/getList')
+        rq.encoding='utf-8'
+        return HttpResponse(json.dumps({'msg':'ok','data':rq.json()}))
+    except:
+        print('无法连接网络数据库,请确定设备是否联网。')
+        return HttpResponse(json.dumps({'msg':'err','data':'无法连接网络数据库,请确定设备是否联网。'}))
+    
+def get_upmodel(request):
+    name=request.GET.get('name')
+    filetype=request.GET.get('type')
+    info=request.GET.get('info')
+    people=request.GET.get('fp_people')
+    files = { 
+    "field1" : (name,open(os.path.dirname(mxpi.__file__)+'/static/file/'+name,"rb"),filetype),
+    } 
+    rq = requests.post(url='http://120.79.209.170/upfile_Ajax',files=files,params={'name':name,'type':filetype,'info':info,'people':people})
+    rq.encoding='utf-8'
+    print(rq.text)
+    return HttpResponse(rq.text)
+
+def downModel(request):
+    id=request.GET.get('id')
+    name=request.GET.get('name')
+    r = requests.get('http://120.79.209.170/downfile_Ajax',params={'id':id}) # 发送请求
+    with open (os.path.dirname(mxpi.__file__)+'/static/file/'+name, 'wb') as f:
+        f.write(r.content)
+        f.close
+    return HttpResponse('ok')    
