@@ -47,7 +47,7 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
         'colour': "#009933",
       },
       'GPIO_category': {
-        'colour': "#009966",
+        'colour': "#c19e10",
       },
       'display_category': {
         'colour': "#FF9900",
@@ -61,6 +61,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'OpenCV_category': {
         'colour': "#0099CC",
       },
+      'blynk_category': {
+        'colour': "#009966",
+      },
       'AI_category': {
         'colour': "#009966",
       },
@@ -106,6 +109,11 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'colourSecondary':"#fff",
       'colourTertiary':"#0099CC"
     }, 
+    'blynk_blocks': {
+      'colourPrimary': "#009966",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#009966"
+    }, 
     'AI_blocks': {
       'colourPrimary': "#009966",
       'colourSecondary':"#fff",
@@ -551,6 +559,7 @@ var i=0
 function clears() {
   var oP = document.querySelector("#cmd_ > div.os-padding > div > div")
   oP.innerHTML = '';
+
 }
 
 function clearss() {
@@ -570,7 +579,7 @@ function mySplit(str,leng){
   function addpip(txt) {
     list_num_pip = list_num_pip+1
     list_nums_pip = list_nums_pip+1
-    if(list_num_pip>2000){
+    if(list_num_pip>1000){
     clearss()
     list_num_pip=0
 	}	
@@ -585,9 +594,10 @@ function mySplit(str,leng){
 function add(txt) {
     list_num = list_num+1
     list_nums = list_nums+1
-    if(list_num>2000){
+    if(list_num>300){
     clears()
     list_num=0
+    list_nums=0
 	}	
     var oP = document.querySelector("#cmd_ > div.os-padding > div > div")
     var oPs =document.createElement("p");
@@ -599,7 +609,7 @@ function add(txt) {
 function adderr(txt) {
   list_num = list_num+1
   list_nums = list_nums+1
-  if(list_num>2000){
+  if(list_num>500){
   clears()
   list_num=0
 }	
@@ -746,7 +756,7 @@ function QuickDemo(){
   resizeOpacity: 1,
 });
 $("#HSV_content").PopupWindow({
-  height      : 650,
+  height      : 660,
   width       : 1000,
   title       : "阈值编辑器",
   autoOpen    : false,
@@ -814,11 +824,94 @@ dragOpacity         : 1,
 resizable:false,
 resizeOpacity: 1,
 });
+  $("#Rexample_content").PopupWindow({
+    height      : 450,
+    width       : 600,
+    title       : "例程",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : false,          // Boolean
+      collapse        : false,          // Boolean
+      minimize        : false,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:false,
+  resizeOpacity: 1,
+  });
+
+  $("#Modelexample_content").PopupWindow({
+    height      : 450,
+    width       : 900,
+    title       : "模型社区",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : false,          // Boolean
+      collapse        : false,          // Boolean
+      minimize        : false,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:false,
+  resizeOpacity: 1,
+  });
+
+  $("#UpModelexample_content").PopupWindow({
+    height      : 450,
+    width       : 900,
+    title       : "发布模型",
+    autoOpen    : false,
+    buttons         : {
+      close           : true,          // Boolean
+      maximize        : false,          // Boolean
+      collapse        : false,          // Boolean
+      minimize        : false,          // Boolean
+  },
+  buttonsTexts        : {
+    close               : "退出",
+    maximize            : "最大化",
+    minimize            : "最小化",
+    collapse            : "搜索",
+  }, 
+  draggable           : true,
+  nativeDrag          : true,
+  dragOpacity         : 1,
+  resizable:false,
+  resizeOpacity: 1,
+  });
+
 
   $("#filemodel").on("click", function(event){
       $("#file_content").PopupWindow("open");
       file_list()
   });
+  $("#Rexample").on("click", function(event){
+    $("#Rexample_content").PopupWindow("open");
+    c_list()
+  });
+  $("#Modelexample").on("click", function(event){
+    $("#Modelexample_content").PopupWindow("open");
+    model_list()
+  });
+  $("#UpModelexample").on("click", function(event){
+    $("#UpModelexample_content").PopupWindow("open");
+  });
   $("#pipmodel").on("click", function(event){
     $("#pip_content").PopupWindow("open");
     pip_list()
@@ -1027,10 +1120,72 @@ function del(data){
     })
 }
 
+$(".upfilemodel").on("change","input[type='file']",function(){
+  document.querySelector("#load-i").style.visibility="visible";
+  var fd = new FormData();
+  fd.append("avatar",$("#i2")[0].files[0]);
+  filenamelist=$("#i2")[0].files[0].name.split('.')
+  filetype=filenamelist[filenamelist.length-1]
+  console.log(filetype)
+  if(filetype=='onnx' || filetype=='pth'){
+  $.ajax({
+      url: '/files',
+      type: 'post',
+      data: fd,
+      contentType: false,  
+      processData: false,
+      xhr: function() { //用以显示上传进度  
+        var xhr = $.ajaxSettings.xhr();
+        if (xhr.upload) {
+              xhr.upload.addEventListener('progress', function(event) {
+                  var percent = Math.floor(event.loaded / event.total * 100); //进度值（百分比制）
+                  console.log(percent)
+                  document.getElementById('fileuppp').innerHTML=percent+'%'
+              }, false);
+            }
+            return xhr
+        },
+      success:function (res) {
+        if(res=='ok'){
+          file_list()
+          document.querySelector("#load-i").style.visibility="hidden";
+          spop({
+            template: '加载成功',
+            position  : 'top-right',
+            autoclose: 1500,
+            style: 'success'
+          });
+          document.getElementById('modelname').innerHTML=$("#i2")[0].files[0].name
+        }
+        else{
+          document.querySelector("#load-i").style.visibility="hidden";
+          spop({
+            template: '加载错误',
+            position  : 'top-right',
+            autoclose: 1500,
+            style: 'error'
+          });
+        }
+      }
+  })
+  }
+  else{
+    spop({
+      template: '上传错误:只能上传后缀名为onnx、pth的模型文件',
+      position  : 'top-right',
+      autoclose: 1500,
+      style: 'error'
+    });
+    document.querySelector("#load-i").style.visibility="hidden";
+  }
+  });
+
+
 $(".upfile").on("change","input[type='file']",function(){
   document.querySelector("#load-ico").style.visibility="visible";
   var fd = new FormData();
   fd.append("avatar",$("#i1")[0].files[0]);
+  console.log(fd)
  $.ajax({
      url: '/files',
      type: 'post',
@@ -1267,13 +1422,122 @@ function pip_list(){
   $("#pip-table").tabulator("setData",[
     {id:1, name:"opencv", col:"opencv库", arr:'arrch64/windows',cheese:re('opencv-python')},
     {id:2, name:"pyqt5",  col:"Pyqt5", arr:'arrch64/windows',cheese:re('pyqt5')},
-    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'arrch64/windows',cheese:re('tensorflow')},
+    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'arrch64/windows',cheese:re('tensorflow==2.8.0')},
     {id:4, name:"Mediapipe",  col:"Mediapipe", arr:'arrch64/windwos',cheese:re('mediapipe')},
     {id:5, name:"sounddevice",  col:"录音与播放音乐", arr:'arrch64/windows',cheese:re('sounddevice')},
     {id:6, name:"SoundFile",  col:"音频文件操作", arr:'arrch64/windows',cheese:re('SoundFile')},
     {id:7, name:"librosa",  col:"用于音乐和音频分析的python包", arr:'arrch64/windows',cheese:re('librosa')},
+    {id:8, name:"hcsr04sensor",  col:"超声波传感器的依赖库", arr:'arrch64',cheese:re('hcsr04sensor')},
   ]);
 }
+
+function c_list(){
+  $("#c-table").tabulator({columns:[
+    {title:"名称", field:"name", sortable:true,align:'center',sorter:"string", width:'30%'},
+    {title:"简介", field:"col", sorter:"string", sortable:false, width:'50%'},
+    {title:"操作", field:"cheese", sortable:true,align:'center',width:'20%'},
+    ],
+    height:'300px',
+    }
+    )
+  $("#c-table").tabulator("setData",[
+    {id:1, name:"打印", col:"循环打印Hello world!",cheese:ce('1')},
+    {id:2, name:"打开摄像头",  col:"OpenCv打开摄像头",cheese:ce('2')},
+    {id:3, name:"画图",  col:"OpenCv画图",cheese:ce('3')},
+    {id:4, name:"发送网络请求",  col:"发送网络请求获取今日天气数据",cheese:ce('4')},
+    {id:5, name:"发送网络请求(带参数)",  col:"发送网络请求获取指定城市当日天气数据",cheese:ce('5')},
+    {id:6, name:"创建桌面应用程序",  col:"PyQt5创建GUI",cheese:ce('6')},
+    {id:7, name:"创建桌面应用程序(交互)",  col:"PyQt5创建交互GUI",cheese:ce('7')},
+    {id:8, name:"调用百度AI",  col:"调用被百度AI进行图像识别",cheese:ce('8')},
+    {id:9, name:"调用百度AI_2",  col:"调用被百度AI进行语音识别",cheese:ce('9')},
+    {id:10, name:"调用百度AI_3",  col:"调用被百度AI进行语音合成",cheese:ce('10')},
+    {id:11, name:"MediaPipe-1", col:"使用MediaPipe进行人脸检测",cheese:ce('11')},
+    {id:12, name:"MediaPipe-2",  col:"使用MediaPipe进行面网",cheese:ce('12')},
+    {id:13, name:"MediaPipe-3",  col:"使用MediaPipe进行手部检测",cheese:ce('13')},
+    {id:14, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
+    {id:15, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
+    {id:16, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
+
+  ]);
+}
+
+function model_list(){
+  $("#model-table").tabulator({columns:[
+    {title:"名称", field:"name", sortable:true,sorter:"string", width:'15%'},
+    {title:"简介", field:"info", sorter:"string", sortable:false, width:'20%'},
+    {title:"类型", field:"star", sortable:true,width:'15%'},
+    {title:"文件大小(M)", field:"file_size", sortable:true,width:'10%'},
+    {title:"上传时间", field:"publish", sortable:true,width:'15%'},
+    {title:"发布人", field:"people", sortable:true,width:'12%'},
+    {title:"操作", field:"down", sortable:true,align:'center',width:'10%'},
+    ],
+    height:'300px',
+    }
+    )
+    $.ajax({
+      url:"./read_model_list",
+      type:"GET",
+      data:{},
+      success:function(data){
+        datas=JSON.parse(data)
+        if(datas.msg=='err'){
+          msg=datas.data
+          spop({
+            template: msg,
+            position  : 'top-right',
+            autoclose: 1500,
+            style: 'error'
+          });
+        }
+        else{
+          spop({
+            template: '连接上网络数据库',
+            position  : 'top-right',
+            autoclose: 1500,
+            style: 'success'
+          });
+          $("#model-table").tabulator("setData",datas.data)
+        }
+        }
+      })
+}
+
+
+function ce(name){
+  return "<div style='display:flex;justify-content: space-around;'><div onclick='get_c(\""+name+"\")'><i class='fa fa-arrow-circle-down' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div></div>"
+}
+
+function get_c(name){
+  $.ajax({
+    url:"./get_c",
+    type:"GET",
+    data:{'name':name},
+    success:function(data){
+      datas=JSON.parse(data)
+      if (datas['msg']=='ok'){
+        workspace.clear();
+        console.log(datas['data'])
+        const xml = Blockly.Xml.textToDom(datas['data']);
+        Blockly.Xml.domToWorkspace(xml, workspace);
+        spop({
+          template: '例程加载成功',
+          position  : 'top-right',
+          autoclose: 1500,
+          style: 'success'
+        });
+      }
+      else{
+        spop({
+          template: '历程加载失败',
+          position  : 'top-right',
+          autoclose: 1500,
+          style: 'error'
+        });
+      }
+      }
+    })
+}
+
 function re(name){
   return "<div style='display:flex;justify-content: space-around;'><div onclick='install_ku(\""+name+"\")'><i class='fa fa-arrow-circle-down' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div></div>"
 }
@@ -1387,4 +1651,105 @@ wavesurfer.on('audioprocess', function () {
   t1=wavesurfer.getDuration().toFixed(3)
   t2=wavesurfer.getCurrentTime().toFixed(3)
   document.getElementById('wav_time1').innerHTML=t2
-});
\ No newline at end of file
+});
+
+function fabumodel(){
+  if ($("#i2")[0].files[0].name){
+  filenamelist=$("#i2")[0].files[0].name.split('.')
+  filetype=filenamelist[filenamelist.length-1]
+  console.log(filetype)
+  if(filetype=='onnx' || filetype=='pth'){
+    info=document.getElementById('model_info').value
+    if (info.length>0){
+      fp_people=document.getElementById('fb_people').value
+      if (fp_people.length>0){
+        $.ajax({
+          url:"./get_upmodel",
+          type:"GET",
+          data:{'name':$("#i2")[0].files[0].name,'type':filetype,'info':info,'fp_people':fp_people},
+          success:function(data){
+            if (data=='ok'){
+              spop({
+                template: '发布成功',
+                position  : 'top-right',
+                autoclose: 1500,
+                style: 'success'
+              });
+              model_list()
+              $("#UpModelexample_content").PopupWindow("close");
+            }
+            else{
+              spop({
+                template: '发布失败',
+                position  : 'top-right',
+                autoclose: 1500,
+                style: 'error'
+              });
+            }
+            }
+          })
+      }
+      else{
+        spop({
+          template: '发布失败,请输入发布人。',
+          position  : 'top-right',
+          autoclose: 1500,
+          style: 'error'
+        });
+      }
+    }
+    else{
+      spop({
+        template: '发布失败,请输入模型简介。',
+        position  : 'top-right',
+        autoclose: 1500,
+        style: 'error'
+      });
+    }
+    
+  }
+  else{
+    spop({
+      template: '发布失败,请先选择模型文件。',
+      position  : 'top-right',
+      autoclose: 1500,
+      style: 'error'
+    });
+  }
+  }
+  else{
+    spop({
+      template: '发布失败,请先选择模型文件。',
+      position  : 'top-right',
+      autoclose: 1500,
+      style: 'error'
+    });
+  }
+}
+
+function downModel(id,name){
+  $.ajax({
+    url:"./downModel",
+    type:"GET",
+    data:{'id':id,'name':name},
+    success:function(data){
+      if (data=='ok'){
+        spop({
+          template: '模型下载成功,请打开文件管理查看',
+          position  : 'top-right',
+          autoclose: 1500,
+          style: 'success'
+        });
+      }
+      else{
+        spop({
+          template: '模型下载失败',
+          position  : 'top-right',
+          autoclose: 1500,
+          style: 'error'
+        });
+      }
+
+      }
+    })
+}
\ No newline at end of file
